#encoding=UTF-8
import os
import cv2
import xml.etree.ElementTree as ET
import shutil
import pdb
from zprint import *
#解析XML文件
def parse_rec_xml(filename_path):
    
    tree = ET.parse(filename_path)
    xml_info = {}
    xml_info['img_name'] = tree.find('filename').text
    xml_info['size'] = {}
    xml_info['size']['width'] = tree.find('size').find('width').text
    xml_info['size']['height'] = tree.find('size').find('height').text
    objects = []
    for obj in tree.findall('object'):
        obj_struct = {}
        obj_struct['R_L'] = obj.find('name').text
        bbox = obj.find('bndbox')
        obj_struct['bbox'] = [int(bbox.find('xmin').text),
                              int(bbox.find('ymin').text),
                              int(bbox.find('xmax').text),
                              int(bbox.find('ymax').text)]
        objects.append(obj_struct)
    xml_info['bbox_info'] = objects
    #return xml_info
    bbox_infos =  xml_info['bbox_info']
    return bbox_infos

#解析TXT文件
def parse_rec_txt(filename_path):
    
    f = open(filename_path)
    txt_info_list = f.readlines()
    f.close()
    txt_info = {}
    for txt_line in txt_info_list:
        txt_line_info = txt_line.strip('\n').split('\t')
        txt_line_value = txt_line_info[2].split(' ')
        txt_info['img_name'] = txt_line_info[0]
        txt_info['rec_num'] = txt_line_info[1]
        objects = []
        for i in range(int(txt_line_info[1])):
            rec_struct = {}
            rec_struct['rank'] = str(i)
            coor_1 = 5 * i
            rec_struct['bbox'] = [float(txt_line_value[coor_1+0]),
                                  float(txt_line_value[coor_1+1]),
                                  float(txt_line_value[coor_1+2]),
                                  float(txt_line_value[coor_1+3])]
            rec_struct['score'] = float(txt_line_value[coor_1+4])
            objects.append(rec_struct)
        txt_info['bbox_info'] = objects
    #return txt_info
    txt_infos = txt_info['bbox_info']
    return txt_infos

#求取重叠率。
def hasOverlap(groud_bbox, pre_bbox):
    if len(pre_bbox) == 0:
        return 0
    else:
        ixmin = max(groud_bbox[0], pre_bbox[0])
        iymin = max(groud_bbox[1], pre_bbox[1])
        ixmax = min(groud_bbox[2], pre_bbox[2])
        iymax = min(groud_bbox[3], pre_bbox[3])
        iw = max(ixmax - ixmin + 1., 0.)    #与0做比较
        ih = max(iymax - iymin + 1., 0.)
        inters = iw * ih                           #重叠面积
        # union  并集
        union = ((pre_bbox[2] - pre_bbox[0] + 1.) * (pre_bbox[3] - pre_bbox[1] + 1.) +
               (groud_bbox[2] - groud_bbox[0] + 1.) *
               (groud_bbox[3] - groud_bbox[1] + 1.) - inters)
        overlaps = inters / union
    return overlaps

def get_goal_name(goal_path):
    name_list = []
    for goal_name in os.listdir(goal_path):
        name = goal_name.split('.')[0] + '.' + goal_name.split('.')[1]
        name_list.append(name)
    return name_list

def get_rect(dir_path, file_name, file_type):
    if file_type ==1:
       file_path = os.path.join(dir_path, file_name + '.xml')
       if os.path.isfile(file_path):
          rect_info = parse_rec_xml(file_path)                # parse xml
       else:
          rect_info = []
    else:
       file_path = os.path.join(dir_path, file_name + '.txt')
       if os.path.isfile(file_path):
          rect_info = parse_rec_txt(file_path)                # parse txt
       else:
          rect_info = []
    return rect_info
        
def match_pre_gt(Prect, gt_rect):
    iou_v = 0
    k = 0
    for i in range(len(gt_rect)):
        iou = hasOverlap(gt_rect[i - k]['bbox'], Prect['bbox'])
        if iou > 0.5:
           del gt_rect[i - k]
           k = k +1 
           iou_v = iou
    return iou_v , gt_rect 
           
def judge_pre_gt(gt_rect, pre_rect, pos, roc_matrix):
    pos = pos + len(gt_rect)
    for Prect in pre_rect:
        iou_v, gt_rect = match_pre_gt(Prect, gt_rect)
        if iou_v > 0.5:
           roc_matrix.append([1, 0, Prect['score']])
        else:
           roc_matrix.append([0, 1, Prect['score']])
    return pos, roc_matrix
    
def get_RocMatrix_and_PosNum(gt_file_path, pre_file_path, gt_type, pre_type):
    gt_name_list = get_goal_name(gt_file_path)      
    pre_name_list = get_goal_name(pre_file_path)    
    gt_name_set = set(gt_name_list)
    pre_name_set = set(pre_name_list)
    gt_pre_name_set = gt_name_set | pre_name_set
    gt_pre_name_list = list(gt_pre_name_set)         
    pos = 0
    roc_matrix = []
    for i in range(len(gt_pre_name_list)):
        gt_rect = get_rect(gt_file_path, gt_pre_name_list[i], gt_type)
        pre_rect = get_rect(pre_file_path, gt_pre_name_list[i], pre_type)
        pos, roc_matrix = judge_pre_gt(gt_rect, pre_rect, pos, roc_matrix)
    return roc_matrix,pos

def get_roc_matrix(gt_path,pre_path):
    
    return get_RocMatrix_and_PosNum(gt_path, pre_path, 1, 0)


if __name__=="__main__":
    path = '/data1/llz/work/hand_llz/'
    gt_merge_path = os.path.join(path, '101968001_gt/')
    pre_merge_path = os.path.join(path, '101968001_pre/')
    
    roc_m,pos_num = get_RocMatrix_and_PosNum(gt_merge_path, pre_merge_path, 1, 0)
    
    zprint("%r,%r"%(pos_num, roc_m)) 
    zprint("%r,%r"%(pos_num, len(roc_m)))



# -*- coding: UTF-8 -*-
import fileinput
from scipy import misc
import sys
import os
import argparse
import numpy as np
import random
from time import sleep
import time
import datetime
import scipy.misc
import hashlib
import urllib2
import json
from DBUtils.PooledDB import PooledDB
import traceback
import cv2
from PIL import Image
import imageio
import shutil
from skimage import io
import os.path
import MySQLdb
import sys

class dbop:
    def __init__(self,hostName="127.0.0.1",usrName="root",passWord="123456",charset="utf8"):
        #pool = PooledDB(MySQLdb,1,host='10.106.5.9',user='oco',passwd='MyNewPass4!',db='task_zmm',port=3306,charset='utf8')
        #self.db = MySQLdb.connect("%s"%(hostName), "%s"%(userName), "%s"%(passWord), "%s"%(dataBase), charset='utf8' )
        #self.db = MySQLdb.connect("%s"%(hostName), "%s"%(usrName), "%s"%(passWord), "%s"%(dataBase), charset='utf8' )
        self.db = MySQLdb.connect("%s"%(hostName), "%s"%(usrName), "%s"%(passWord), charset='utf8' )
    def po(self,message):
        print(message)

    def turple2list(self,turple_val):
        rlist = lambda t, self=lambda t, self: [self (tt, self ) for tt in t] if isinstance (t, tuple ) else t: self (t, self )
        #rlist (((1,),(1,(1,2,3,(4,5 )))))
        rl=rlist (turple_val)
        return rl

    def run(self,sqlstr):
       
        cursor = self.db.cursor()
        content=None
        try:
            #sql = "SELECT xml_content FROM %sxml WHERE image_name = '%s'"%(project_name,image_name)
            #sql = "SELECT xml_content FROM %sxml WHERE image_name = '%s'"%(project_name,image_name)
            cursor.execute(sqlstr)
            content = cursor.fetchall()
        except Exception as e:
            self.po(sqlstr)
            self.po(e)
        self.db.commit()
        return self.turple2list(content)
    def help(self,name='sql'):
        if name=="sql":
            self.po("SELECT ziduan FROM %sxml WHERE image_name = '%s'")
            self.po("INSERT INTO %sxml (image_name, xml_content) VALUES ('%s','%s')")
            self.po("UPDATE %sxml SET xml_content = '%s' WHERE image_name = '%s'")
            self.po("select count(*) from %s_task  where status='finished' and teacher_id=%d")
            self.po("insert into  audio_flvs(online_class_id,info,created_at,updated_at) values(%d,'%s',now(),now())")
            self.po('delete from video_flvs where online_class_id=%d')
            self.po("insert into  video_flvs(online_class_id,info,created_at,updated_at) values(%d,'%s',now(),now())")

    def getnum(self,rr):
        num=0
        if rr is None:
            num+=0
        else:
            num+=rr[0][0]
        return num

    
    def get_task_num(projectname,host_id,status):
        #sqlstr="select online_class_id,info from %s_task  where status='%s' and host_id=%d order by id limit 1"%(projectname,status,host_id)
        sqlstr="select count(*) from %s_task  where status='%s' and host_id=%d"%(project_name,status,host_id)
        rr=self.run(sqlstr)
        return self.getnum(rr) 

    def get_finished_num_by_teacher_id(self,project_name,teacher_id,host_id):
        task_sql="select count(*) from %s_task  where status='finished' and teacher_id=%d"%(project_name,teacher_id)
        rr=self.run(sqlstr)
        return self.getnum(rr) 
    def get_task_list_from_db(self,project_name,host_id,pre_log_str):
        sqlstr="select online_class_id,supplier_code,student_id,teacher_id,class_room as classroom,scheduled_date_time,course_id,student_id,birthday,english_name,teacher_1_avatar_url,teacher_2_avatar_url,teacher_3_avatar_url,teacher_4_avatar_url from %s_task  where status in ('insert') and host_id=%d  order by id limit 1"%(project_name,host_id)
        rr=self.run(sqlstr)
        tl=self.tasklist2dict(rr) 
        return tl 
    def update_finished_num(self,project_name,teacher_id,finished_num):
        sqlstr="update %_task set finished_num=%d,updated_at=now() where teacher_id=%d "%(project_name,finished_num,teacher_id)
        rr=self.run(sqlstr)
        return self.getnum(rr) 
    def update_finished_teacher_id_status_as_repeate(self,project_name,teacher_id,pre_log_str):
        sqlstr="update %s_task set status='repeate',updated_at=now() where teacher_id=%d and status='new'"%(project_name,teacher_id)
        rr=self.run(sqlstr)
        return rr
    def connect(self,project_name):
        #pool = PooledDB(MySQLdb,1,host='10.106.5.9',user='oco',passwd='MyNewPass4!',db='task_zmm',port=3306,charset='utf8')
        #pool = PooledDB(MySQLdb,1,host='122.152.206.246',user='oco',passwd='MyNewPass4!',db='task_zmm',port=3306,charset='utf8')
        pool = PooledDB(MySQLdb,1,host='127.0.0.1',user='root',passwd='MyNewPass4!',db='%s_task'%(project_name),port=3306,charset='utf8')
        return pool
    
    def get_task_list_by_hand(pre_log_str):
        pre_log_str+=sys._getframe().f_code.co_name+':'
        log2(pre_log_str+'[start]')
        '''
        #distinct teacher_id,oc.id,scheduled_date_time,course_id,class_type,supplier_code,student_id,classroom 
        #4975    10024634        2017-01-12 21:30:00.0   5102    0       2       1873263 jz0e4ce371ad9643529c07d46fa2b473f6
        #9466032 2010-05-01      cindy   88908548        597816  jz50c2c134629f454da020f0da757a3fa0      2018-03-29 19:00:00.0   2       1792256,https://teacher-media.vipkid.com.cn/teacher/avatar/1792256/avatar_large/image_20161222190339_76221a2e558849d9a88e86e5962cd9b1.png|10085815,https://teacher-media.vipkid.com.cn/teacher/avatar/10085815/avatar_large/image_20171201235242_622f7edbf62c40a28fda623e2c716e34.png|8286866,https://teacher-media.vipkid.com.cn/teacher/avatar/8286866/avatar_large/image_20171015192213_df2997251d474eb588ccbd406898cefd.png|8613024,https://teacher-media.vipkid.com.cn/teacher/avatar/8613024/avatar_large/image_20171021131609_f0a47d44232a4472ba7180abeb16c3a0.png
        #1295483 2009-05-23      Kitty   94979870        597816  jz08c045b4d10a43d79a69f7df847874dc      2018-04-24 19:00:00.0   7       1076218,https://teacher-media.vipkid.com.cn/teacher/avatar/1076218/avatar_large/image_20161222185510_87385003166546b8a1b740b395f19626.png|2312087,https://teacher-media.vipkid.com.cn/teacher/avatar/2312087/avatar_large/image_20161222191249_eb124b8f82e140aebbbb5b8dda51e614.png|5675039,https://teacher-media.vipkid.com.cn/teacher/avatar/5675039/avatar_large/image_20171231002452_f6af238df0f44821acad7c6afe593591.png|2031380,https://teacher-media.vipkid.com.cn/teacher/avatar/2031380/avatar_large/image_20161222190714_8300ec7c9d784b15943413b2cd6e07be.png
        '''
        task_list=[]
        task_dict={}
        task_dict['online_class_id']=93363743
        task_dict['supplier_code']=8
        task_dict['student_id']=1896711
        task_dict['teacher_id']=7832201
        task_dict['classroom']='jz721ee6b1cff04559a597a6572d9f00d1'
        task_dict['scheduled_date_time']='2018-04-26 18:00:00'
        task_list.append(task_dict)
        log2(pre_log_str+'[  end]')
    
        return task_list
    def tasklist2dict(self,rr): 
        task_list=[]
        for rrr in rr:
           task=rrr
           online_class_id=task[0]
           #info=task[1]
           task_dict={}
           task_dict['online_class_id']=int(task[0])
           task_dict['supplier_code']=int(task[1])
           task_dict['student_id']=int(task[2])
           task_dict['teacher_id']=int(task[3])
           task_dict['course_id']=int(task[6])
           #task_dict['class_type']=int(task[7])
           task_dict['classroom']=str(task[4])
           task_dict['scheduled_date_time']=str(task[5])
           task_dict['student_id']=int(task[7])
           task_dict['birthday']=str(task[8])
           task_dict['english_name']=str(task[9])
           task_dict['teacher_1_avatar_url']=str(task[10])
           task_dict['teacher_2_avatar_url']=str(task[11])
           task_dict['teacher_3_avatar_url']=str(task[12])
           task_dict['teacher_4_avatar_url']=str(task[13])
           #task_dict = json.loads(info)
           task_list.append(task_dict)
        return task_list
    
if __name__=="__main__":
    #pool = PooledDB(MySQLdb,1,host='122.152.206.246',user='oco',passwd='MyNewPass4!',db='task_zmm',port=3306,charset='utf8')
    #dbb0=dbop("122.152.206.246","oco","MyNewPass4!")
    #db0l=dbb0.run("show databases;")
    #print(db0l)
    dbb=dbop("172.23.250.51","root","20180712")
    dbl=dbb.run("show databases;") 
    #print dbb.run("use test0720")
    #print dbb.run("desc test0720xml")
    xml_num=0
    jpg_num=0
    for dbname in dbl:
        if "fourgesture_detection_train" not in  dbname[0]:
            continue
        #print dbname
        sqlstr="use %s;"%(dbname[0])
        dbb.run(sqlstr) 
        sqlstr="select count(*) from %sxml;"%(dbname[0])
	rr=dbb.run(sqlstr) 
        xml_num+=dbb.getnum(rr)
        xml_numtmp=dbb.getnum(rr)
        sqlstr="select count(*) from %simg"%(dbname[0])
	rr=dbb.run(sqlstr) 
        jpg_num+=dbb.getnum(rr)
        jpg_numtmp=dbb.getnum(rr)
        if xml_numtmp>0:
            print dbname[0]
	    print "xmltmp:%d,jpgtmp:%s"%(xml_numtmp,jpg_numtmp)
	    print "xml:%d,jpg:%s"%(xml_num,jpg_num)
    print dbb.help("sql") 
    #print len(dbl)
    #print type(list(dbl))
    #for db in dbl:
    #    print list(db)



import numpy
import numpy as np
import imageio
from ai_tools import video2img as vi
from vcvf_emotion import face_emotion as fe
from distutils.sysconfig import get_python_lib
from sklearn.externals import joblib
import pdb
import os
import cv2
import sys
from zprint import *
os.environ["CUDA_VISIBLE_DEVICES"] = "-1"
#fe0=fe.face_emotion()
sppath=get_python_lib()
mpath=os.path.join(sppath,"ai_tools/data/wjdc_clf_800.pkl")
print("%s exits: %s"%(mpath,os.path.exists(mpath)))
clf_wjdc=joblib.load(mpath)
def init():
    global fe0
    fe0=fe.face_emotion()
def get_imglist_face_emotion(images):
    global fe0
    smile_image=[]
    smile_score_l=[]
    top_l=[]
    left_l=[]
    size_l=[]
    c=1
    for img in images:
        #rect=[96,96,185,186]
        #print(fe0.face_emotion_rect(img,rect))
        score,rect,time_cost=fe0.face_emotion(img)
        if(len(score)==0):
            score.append(0)
        if(len(rect)==0):
            rect.append(fe0.rect_opencv2dlib([1,1,2,2]))
        sys.stdout.write("\r"+40*" ")
        sys.stdout.write("\r%5s/%5s,%5s,%15s"%(c,len(images),score,rect))
        sys.stdout.flush()
        dl=rect
        sl=score
        #pdb.set_trace()
        smile_score_l.append(sl[0])
        top_l.append(float(dl[0].top())/float(img.shape[0]))
        left_l.append(float(dl[0].left())/float(img.shape[1]))
        size_l.append(  float(float(dl[0].bottom())-float(dl[0].top()))/float(img.shape[0]))
        if(sl[0]>0.8):
            smile_image.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
        c=c+1
    return smile_score_l,top_l,left_l,size_l,smile_image 
def list2matrix(smile_score_l,top_l,left_l,size_l):
     #pdb.set_trace() 
     x0=np.zeros((len(top_l),4))
     x0[:,0]=np.array(smile_score_l)
     x0[:,1]=np.array(top_l)
     x0[:,2]=np.array(left_l)
     x0[:,3]=np.array(size_l)
     x1=cv2.resize(x0,(800,4),cv2.INTER_CUBIC) 
     feature=x1.reshape((1,x1.shape[0]*x1.shape[1]))
     return feature
def write2file(ffn,smile_score_l,top_l,left_l,size_l):
     #ffn="wjdcfeature_rate_1/%s_%s.wjdc.txt"%(lumi_class,infostrl[0])
     ffnh=open(ffn,'w')
     for i in range(0,len(top_l)):
         ffnh.write("%s,"%(smile_score_l[i]))
         ffnh.write("%s,"%(top_l[i]))
         ffnh.write("%s,"%(left_l[i]))
         ffnh.write("%s\n"%(size_l[i]))
     ffnh.close()
    
def get_wjdc_feature(video_url,wget_flag=1,rate=0.1):
    if(wget_flag==1):
        images=vi.flv2img_wget(video_url,rate,0,4000)
    else:
        images=vi.flv2img(video_url,rate,0,4000)
    zprint("images:%s"%(len(images)))
    sm_l,top_l,left_l,size_l,simg_l=get_imglist_face_emotion(images)
    feature=list2matrix(sm_l,top_l,left_l,size_l)
    return feature
def wjdc_classify(video_url,wget_flag=1,rate=0.1):
    global clf_wjdc 
    x=get_wjdc_feature(video_url,wget_flag,rate)
    #pdb.set_trace()
    re=wjdc_classify_from_feature(x)
    return re
def wjdc_classify_from_feature(x):
    global clf_wjdc 
    y_pred = clf_wjdc.predict_proba(x)
    zprint("y_pred=%s"%(y_pred))
    y_pred_sort_index=np.argsort(y_pred)
    y_pred_l=y_pred_sort_index[:,-1]
    #ddict=["wjdc","nwjdc"]
    ddict=["nwjdc","wjdc"]
    zprint(ddict[y_pred_l[0]])
    return ddict[y_pred_l[0]]
def work1(video_url,class_id):
    images=vi.flv2img_wget(video_url,1,0,4000)
    sm_l,top_l,left_l,size_l,simg_l=get_imglist_face_emotion(images)
    ffn="wjdcfeature_test1k/%s_%s.wjdc.txt"%("test",class_id)
    write2file(ffn,sm_l,top_l,left_l,size_l)
    
    print(ffn)
    return simg_l
if __name__=="__main__":
    
    argsl=sys.argv[1].strip("\n").split(" ")
    print(argsl)
    role=argsl[0]
    video_url=argsl[1]
    class_id=argsl[2]
    #print(get_wjdc_feature(sys.argv[1]))
    #work1(video_url,class_id)
    wjdc_classify(video_url,0)




# -*- coding: utf-8 -*-

import cv2
import os
from vcvf import face_detector as fd
import math
import threading
import time
from zprint import *
import numpy as np
import pdb
def faceimg(flv="ceshivedio.flv",rate=0.3,star=1,end=100):
    start_time = time.time()
    fd1=fd.face_detector()
    face=flv2img(flv,rate,star,end)
    face_list=[]
    for i in range(len(face)):
        img=face[i]
        try:
            num,list1,timecost=fd1.detect_face(img)
        except Exception as e:
            zprint(e)
            num=0
        if num>=1:
            face_list.append(img)
    elapse_time = time.time() - start_time
    zprint( "faceimg use time:%f,face_number:%d/%d"%(elapse_time,len(face_list),len(face)))
    return face_list,elapse_time

def fiter_face(imglist,fdd):
    t1=time.time()
    list(map(lambda x:fdd.detect_face(x) ,imglist))
    t2=time.time()
    #print len(rval),t2-t1
    print t2-t1
def fiter_face1(face,fdd):
    start_time = time.time()
    face_list=[]
    for i in range(len(face)):
        img=face[i]
        try:
            num,list1,timecost=fdd.detect_face(img)
        except Exception as e:
            zprint(e)
            num=0
        if num>=1:
            face_list.append(img)
    elapse_time = time.time() - start_time
    zprint( "faceimg use time:%f,face_number:%d/%d"%(elapse_time,len(face_list),len(face)))

def flv2img(flv="ceshivedio.flv",rate=0.3,star=1,end=100):

    list_all=[]
    vc=cv2.VideoCapture(flv)
    c=1
    fps=dps(flv)
    #fps=fps/rate
    if rate>fps:
       zprint("the fps is %s, set the rate=fps"%(fps))
       rate=fps
    if vc.isOpened():
        rval=True
    else:
        rval=False

    j=1.0
    count=0.0
    while rval:
        #pdb.set_trace()
        count=fps/rate*(j-1)
        rval,frame=vc.read()
        if (c-1)==int(count):
            j+=1
            #zprint( frame,"\naaaaaaaaaaaaa"
            #raw_input()
            #zprint( math.floor(c/fps),
            #break
            if (math.floor(c/fps))>=star and (math.floor(c/fps))<end:
                #zprint( frame
                #raw_input()
                if frame is not None:
                   list_all.append(frame)
                #else:
                #   zprint(("img is None")

        c+=1
        #pdb.set_trace()
        #zprint("%s,%s,%s"%(int(count),c-2,end))
        #if len(list_all)>end or (math.floor(c/fps))>=end:
        if (math.floor(c/fps))>=end:
            break

    #if len(list_all)<(end-star+1):
    #    zprint( "Sorry,pictures are not enough")
    #zprint( list_all
    zprint("[ %d ] pictures from '%s' "%(len(list_all),flv))
    vc.release()
    return list_all
def flv2img_wget(flv="ceshivedio.flv",rate=0.3,star=1,end=100):
    zprint("start donwload: %s"%(flv))
    os.system("wget %s -q -O tmp.v"%(flv))
    zprint("complete donwload: %s"%(flv))
    return flv2img("tmp.v",rate,star,end)
def video2img(flv,rate=0.3,star=1,end=100):
    vc=cv2.VideoCapture(flv)
    fps=dps(flv)
    rval=vc.isOpened()
         

def dps(vedio):
    video = cv2.VideoCapture(vedio)
    (major_ver, minor_ver, subminor_ver) = (cv2.__version__).split('.')
    fps = video.get(cv2.CAP_PROP_FPS)
    video.release()
    return fps


if __name__=="__main__":
    fd1=fd.face_detector()
    videofile="/data1/case_study65/flvs/video/student/20180502/97535447_1525257000_out-video-jz320d98a2e0e04390be9aa2c8e4c42e8a_f_1525258221981_t_1525258392191.flv"
    #videofile="tmp.v"
    videofile="https://vps-ve.vipkid.com.cn/videoedit/prod/projects/fifthanniversary/6978981/fifth_anniversary_6978981_final_video.mp4"
    #imglist=flv2img(videofile,0.01,1.5,120.3)
    imglist=flv2img_wget(videofile,0.01,1.5,120.3)
    fiter_face(imglist,fd1)
    fiter_face1(imglist,fd1)




# -*- coding: utf-8 -*-
import os
import os.path
import xml.dom.minidom
import sys
import MySQLdb
from PIL import Image
import time
from zprint import *

reload(sys) 
sys.setdefaultencoding('utf-8')

def con_db1():
    hostName = "172.23.250.51"
    userName = "root"
    passWord = "20180712"
    #dataBase = "ground_truth"
    #dataBase = project_name
    charset = "utf8"
    db = MySQLdb.connect("%s"%(hostName), "%s"%(userName), "%s"%(passWord), charset='utf8' )

    return db

def insert_project2db(projectName,localpath):
    
    db = con_db1()
    cursor = db.cursor()

    cursor.execute("CREATE DATABASE if not exists %s DEFAULT CHARACTER SET utf8" % projectName)
    cursor.execute("USE %s" % projectName)
    #create xml table
    xmlTbName = projectName+'xml'
    sql = "Create table if not exists %s (id int(10) unsigned primary key auto_increment, image_name varchar(200), xml_content varchar(2000), marker_id char(20)) default character set utf8"%  xmlTbName
    cursor.execute(sql)
    db.commit()
    #create imagetable
    imgTbName = projectName+'img'
    sql = "Create table if not exists %s (id int(10) unsigned primary key auto_increment, image_name varchar(200), raw_data longblob, is_marking char(20) default 'no', if_verify char(20) default 'no') default character set utf8"% imgTbName
    cursor.execute(sql)

    cc=0
    for imagefile in os.listdir(localpath):
        cc+=1
        print "[%d,%s]"%(cc,os.path.join(localpath,imagefile))
        Image.open(os.path.join(localpath,imagefile)).save("tmp.png")
        #with open(os.path.join(localpath, imagefile), "rb") as f:
        with open("tmp.png", "rb") as f:
            img_data = f.read()
            f.close()
        image_name = str(imagefile)[:-4]
        sql = "INSERT INTO %s (image_name, raw_data) VALUES ('%s', '%s')" % (imgTbName, image_name, MySQLdb.escape_string(img_data))
        cursor.execute(sql)
        db.commit()

    cursor.close()
    db.close()

def con_db2():
    hostName = "172.23.250.28"
    userName = "root"
    passWord = "MyNewPass4!"
    dataBase = "labelImg_monitor_task"
    charset = "utf8"
    db = MySQLdb.connect("%s"%(hostName), "%s"%(userName), "%s"%(passWord), "%s"%(dataBase), charset='utf8' )

    return db

def get_class_info(class_id_str,insertflag=1):
    info_list_l=[]
    db = con_db2()
    cursor = db.cursor()
    tbName = "labelImg_monitor_task"
    insert_status = 'insert'
    can_status = 'can_download'
    done_status = 'download_done'
    cannot_status = 'cannot_download'
    class_ids=class_id_str.split(',')
    for class_id in class_ids:
	if insertflag==1:
        	sql = "INSERT INTO %s (online_class_id, status) VALUES (%d, '%s')" % (tbName, int(class_id), insert_status)
	else:
		sql = "delete from %s where online_class_id=%s"%(tbName,int(class_id))
        	cursor.execute(sql)
        	sql = "INSERT INTO %s (online_class_id, status) VALUES (%d, '%s')" % (tbName, int(class_id), insert_status)
		#sql = "update %s set status='%s' where online_class_id=%s"%(tbName,insert_status,int(class_id))
        cursor.execute(sql)
    print "%s is ok!"% sql
    db.commit()
    for class_id in class_ids:
        sql = "SELECT status FROM %s WHERE online_class_id = %d LIMIT 1"%(tbName, int(class_id))
        #the longgest query time is 20s
        for i in range(0,80):
            zprintr(sql)
            db.commit()
            cursor.execute(sql)
            curr_status = cursor.fetchone()[0]
            zprintr( "%d s: Query again.curr_status: %s"%((i*5), curr_status))
            if curr_status == can_status:
                zprint("%d s passed."%(i*5))
                zprint("Now the status of %s is %s."%(class_id, curr_status))
                break
            elif curr_status == cannot_status:
                zprint("Now the status of %s is %s."%(class_id, curr_status))
                return [False, curr_status]
            time.sleep(5)
            if i == 99 and curr_status != can_status:
                zprint("Now the status of %s is %s."%(class_id, curr_status))
                return [False, curr_status]
        #info: online_class_id,supplier_code,student_id, teacher_id,classroom, scheduled_date_time
        sql = "SELECT online_class_id, supplier_code, student_id,teacher_id, class_room, scheduled_date_time FROM %s WHERE online_class_id = %d LIMIT 1"%(tbName, int(class_id))
        cursor.execute(sql)
        info_tuple = cursor.fetchone()
        print info_tuple
        info_list = list(tuple(info_tuple))
        info_list[-1]=info_list[-1].strftime("%Y-%m-%d %H:%M:%S")
        print "info_list: ", info_list
        info_list_l.append(info_list)
    db.commit()
    db.close()
    return info_list_l
 
def updateDb(class_id, status):

    db = con_db2()
    cursor = db.cursor()
    tbName = "labelImg_monitor_task"

    sql = "UPDATE %s SET status = '%s' WHERE online_class_id  = %d" % (tbName, status, int(class_id))
    cursor.execute(sql)
    print "%s is ok."%sql
    db.commit()
    db.close()
#insert_project2db("download_try_123732774", "D:/file/try/try")
#insert_project2db("test0802wu","D:/file/try/try")
if __name__=="__main__":
    class_id=137946928
    class_id=137825379
    class_id=137243710
    class_id="137434266,137483549"
    class_id="136087333,135838281"
    class_id="136819472,137829699"
    class_id="136812550,136736262,135863774,137921226,137868755,137226610,135883148,137379131,136212977,137950702,137462084,135823448,137731053,135901211,137306710,135758923,137807125,136841142,135008263,136522226,136819218,136170925,137750547,137228421,135896205,135932609,137865776,123300682,137201733,136475716,136736570,137868931,135793858,135983779,137930552,137881030,137072776,135898487"
    info_list=get_class_info(class_id)
    print(info_list)
    



import cognitive_face as CF
import json
import numpy as np
import sys
from zprint import *

def init():
    #KEY = 'subscription key'  # Replace with a valid Subscription Key here.
    #KEY = '74bc910571cd4785991d003b30c2a783'
    #KEY = '6a78402ab44140aba9e2014e0c7263ea'
    KEY = '8f7fbf07deb944258ff459ef22b1fac2'
    CF.Key.set(KEY)
    #https://eastasia.api.cognitive.microsoft.com/face/v1.0
    #BASE_URL = 'https://westus.api.cognitive.microsoft.com/face/v1.0/'  # Replace with your regional Base URL
    BASE_URL = 'https://eastasia.api.cognitive.microsoft.com/face/v1.0'
    CF.BaseUrl.set(BASE_URL)
    #img_url = 'https://raw.githubusercontent.com/Microsoft/Cognitive-Face-Windows/master/Data/detection1.jpg'
    return CF
def detect(CF,img_url):
    #img_url = 'https://raw.githubusercontent.com/Microsoft/Cognitive-Face-Windows/master/Data/detection1.jpg'
    try:
        result = CF.face.detect(img_url)
        return result
    except Exception as e:
        eprint("%s"%(e))
        eprint("img_url:%s"%(img_url))
        #print(e)
        #return detect(CF,img_url)
        return []

def ms_face_detect(img_url):
    CF=init()
    result=detect(CF,img_url)
    #print(result)
    cc=0
    rects=[]
    faceids=[]
    for re in result:
        #{u'faceId': u'4076f1f6-3461-4c8b-9113-647e17230d85', u'faceRectangle': {u'width': 101, u'top': 67, u'height': 101, u'left': 137}}
        cc+=1
        #np.array((0,0,faces[0][0],faces[0][1])) 
        #print cc
        rer=re[u'faceRectangle']
        #print rer[u'width']
        #print rer[u'top']
        #print rer[u'height']
        #print rer[u'left']
        #dic=json.loads(re)
        #print dic
        rects.append(np.array((rer[u'left'],rer[u'top'],rer[u'width'],rer[u'height'])))
        faceids.append(re[u'faceId'])
    return rects

def ms_face_verify(CF,img_url1,img_url2):
     result1=detect(CF,img_url1)
     result2=detect(CF,img_url2)
     confidence_list=[]
     for re1 in result1:
         #print re1
         for re2 in result2:
             #print re2
             vr=CF.face.verify(re1[u'faceId'],re2[u'faceId'])
             confidence=vr[u'confidence']
             #print confidence
             confidence_list.append(confidence)
     return confidence_list


img_url = 'https://raw.githubusercontent.com/Microsoft/Cognitive-Face-Windows/master/Data/detection1.jpg'
img_url2 = '/data1/mingmingzhao/label/data_sets_teacher_1w/47017613_1510574400_out-video-jzc70f41fa6f7145b4b66738f81f082b65_f_1510574403268_t_1510575931221.flv_0001.jpg'
#print(ms_face_detect(img_url))
CF=init()
cl=ms_face_verify(CF,img_url,img_url2)
print cl




# coding:utf-8
import sys


def txt2html(res_file,title_list_str,attach_info):

    TABLE = '<table>'
    TR = "<tr>"
    TD = "<td>"
    C_TABLE = "</table>"
    C_TR = "</tr>"
    C_TD = "</td>"
    title_list=title_list_str.split(",") 
    title_length=len(title_list)

    tableContent = '<table border="1"; style="border-collapse:collapse;text-align:left;">'
    tableContent += '<tr bgcolor="#CCCCCC">'
    for title in title_list:
        tableContent += '<td>%s</td>'%(title)
    tableContent += '</tr>'

    with open(res_file) as f:
        for line in f:
            items = line.strip().split(" ")
            tableContent += TR
            for item in items:
                tableContent += TD + str(item) + C_TD 
            tableContent += C_TR

    tableContent += C_TABLE

    mailContent = "<html>"
    mailContent += "<div style=\"text-align:center;\"><h3> 数据报告 </h3></div>"
    mailContent += "<p></p>"
    #mailContent += "<p>注：情感分取值[0,1], 值越大情感越正向。下表为每日情感分低于0.5的评论</p>"
    mailContent += "<p>%s</p>"%(attach_info)
    mailContent += tableContent
    mailContent += '</br>'
    mailContent += '</html>'

    #return tableContent
    print(mailContent)
    return mailContent


if __name__=="__main__":
    
    #txt2html("res.txt","t1,t2,t3.t4","import info")
    txt2html(sys.argv[1],sys.argv[2],sys.argv[3])




import numpy
import numpy as np
import imageio
from ai_tools import video2img as vi
#from vcvf_emotion import face_emotion as fe
import pdb
import os
import cv2
import sys
import numpy
import imageio
from ai_tools import video2img as vi
import pdb
import os
import cv2
import sys           
from zprint import *
os.environ['CUDA_VISIBLE_DEVICES']="-1"

#fe0=fe.face_emotion()
def get_face_emotion_from_imglist(images):
    smile_image=[]
    smile_score_l=[]
    top_l=[]
    left_l=[]
    size_l=[]
    c=1
    for img in images:
        #rect=[96,96,185,186]
        #print(fe0.face_emotion_rect(img,rect))
        score,rect,time_cost=fe0.face_emotion(img)
        if(len(score)==0):
            score.append(0)
        if(len(rect)==0):
            rect.append(fe0.rect_opencv2dlib([1,1,2,2]))
        sys.stdout.write("\r"+40*" ")
        sys.stdout.write("\r%5s/%5s,%5s,%15s"%(c,len(images),score,rect))
        sys.stdout.flush()
        dl=rect
        sl=score
        #pdb.set_trace()
        smile_score_l.append(sl[0])
        top_l.append(float(dl[0].top())/float(img.shape[0]))
        left_l.append(float(dl[0].left())/float(img.shape[1]))
        size_l.append(  float(float(dl[0].bottom())-float(dl[0].top()))/float(img.shape[0]))
        if(sl[0]>0.8):
            smile_image.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
        c=c+1
    return smile_score_l,top_l,left_l,size_l,smile_image 
def list2matrix(smile_score_l,top_l,left_l,size_l):
     #pdb.set_trace() 
     x0=np.zeros((len(top_l),4))
     x0[:,0]=np.array(smile_score_l)
     x0[:,1]=np.array(top_l)
     x0[:,2]=np.array(left_l)
     x0[:,3]=np.array(size_l)
     x1=cv2.resize(x0,(800,4),cv2.INTER_CUBIC) 
     return x1
def write2file(ffn,smile_score_l,top_l,left_l,size_l):
     #ffn="wjdcfeature_rate_1/%s_%s.wjdc.txt"%(lumi_class,infostrl[0])
     ffnh=open(ffn,'w')
     for i in range(0,len(top_l)):
         ffnh.write("%s,"%(smile_score_l[i]))
         ffnh.write("%s,"%(top_l[i]))
         ffnh.write("%s,"%(left_l[i]))
         ffnh.write("%s\n"%(size_l[i]))
     ffnh.close()
    
def get_wjdc_feature(video_url):
    images=vi.flv2img(video_url,0.1,0,4000)
    sm_l,top_l,left_l,size_l,simg_l=get_face_emotion_from_imglist(images)
    x1=list2matrix(sm_l,top_l,left_l,size_l)
    return x1
def work1(video_url,class_id):
    images=vi.flv2img_wget(video_url,1,0,4000)
    sm_l,top_l,left_l,size_l,simg_l=get_imglist_face_emotion(images)
    ffn="wjdcfeature_test1k/%s_%s.wjdc.txt"%("test",class_id)
    write2file(ffn,sm_l,top_l,left_l,size_l)
    
    print(ffn)
    return simg_l
def demo1():    
    argsl=sys.argv[1].strip("\n").split(" ")
    print(argsl)
    role=argsl[0]
    video_url=argsl[1]
    class_id=argsl[2]
    #print(get_wjdc_feature(sys.argv[1]))
    work1(video_url,class_id)
def get_smile(images):
    images_smile=[]
    c=1
    for img in images:
        #rect=[96,96,185,186]
        #print(fe0.face_emotion_rect(img,rect))
        score,rect,time_cost=fe0.face_emotion(img)
	if(len(score)>0 and score[0]>0.8):
        	#images_smile.append(img)
        	images_smile.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
        	sys.stdout.write("\rlen(images),len(smile)=[%d,%d/%d],score=%s,%s"%(len(images),len(images_smile),c,score,score[0]>0.8))
        c=c+1
    return images_smile
def create_gif(gif_name,video_url):
    images=vi.flv2img(video_url,1,0,4000)
    image_smile=get_smile(images)

    dura=0.1
    #images=imageio.imiread("qq.gif")
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,53,12))]),duration=0.00001)
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,50,2))]),duration=0.1)
    imageio.mimsave(gif_name+"%s.gif"%(len(image_smile)*0.05),list(numpy.array(image_smile)[numpy.array(range(0,len(image_smile),2))]),duration=dura)
    print("gif duraton:%s s"%(len(image_smile)*0.1*0.5))
def create_gif_from_imglist(gif_name,images):
    #images=vi.flv2img_wget(video_url,1,0,4000)
    #image_smile=get_smile(images)
    image_smile=images

    dura=0.1
    #images=imageio.imiread("qq.gif")
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,53,12))]),duration=0.00001)
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,50,2))]),duration=0.1)
    imageio.mimsave(gif_name+"%s.gif"%(len(image_smile)*0.05),list(numpy.array(image_smile)[numpy.array(range(0,len(image_smile),2))]),duration=dura)
    print("gif duraton:%s s"%(len(image_smile)*0.1*0.5))
def demo2():
    base_url="/data1/mingmingzhao/data_sets/mp4/"
    video_all="vipkid_jz3bc4e1e7458f49a381297ee384773637_f_1522312337659_t_1522313938697.mp4,vipkid_jz40c0afcf42a54577ae80a668a8593600_f_1532087814504_t_1532089561969.mp4,vipkid_jz932a9ba4f1fd4fd5809b333a366dd64a_f_1530336593475_t_1530338142709.mp4,vipkid_jzbfad3425917946f0abaafaea966117a9_f_1531744118258_t_1531745977835.mp4,vipkid_jzc0fc4672202b492594b3d094b010a6e1_f_1531826923257_t_1531828692939.mp4,vipkid_jzd28621035a7c4304805b38d397d148ae_f_1530872632184_t_1530874638548.mp4"
    video_list=video_all.split(',')
    for video in video_list:
        video_url=os.path.join(base_url,video)
        gif_name=video.split("_")[1]
        #pdb.set_trace()
        create_gif(gif_name,video_url)
def analysis_teacher(teacher_url,fe1):
    zprint("downloading:%s"%(teacher_url))
    imgs=vi.flv2img_wget(teacher_url,1,0,100)
    face_num=0
    smile_num=0
    hand_num=0
    c=0
    smile_score_l=[]
    top_l=[]
    left_l=[]
    size_l=[]
    smile_image=[]
    for img in imgs:
        score,rect,time_cost=fe1.face_emotion(img)
        
        if(len(score)==0):
            score.append(0)
        else:
            face_num+=1
        if(len(rect)==0):
            rect.append(fe1.rect_opencv2dlib([1,1,2,2]))
        sys.stdout.write("\r"+40*" ")
        sys.stdout.write("\r%5s/%5s,%5s,%15s"%(c,len(imgs),score,rect))
        sys.stdout.flush()
        dl=rect
        sl=score
        #pdb.set_trace()
        smile_score_l.append(sl[0])
        top_l.append(float(dl[0].top())/float(img.shape[0]))
        left_l.append(float(dl[0].left())/float(img.shape[1]))
        size_l.append(  float(float(dl[0].bottom())-float(dl[0].top()))/float(img.shape[0]))
        if(sl[0]>0.8):
            smile_image.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
            smile_num+=1
        c+=1
    info={"smile_image":smile_image,"face_num":face_num,"smile_num":smile_num,"hand_num":hand_num,"smile_score_l":smile_score_l,"top_l":top_l,"left_l":left_l,"size_l":size_l}
    #return face_num,smile_num,hand_num
    return info
def analysis_student(student_url,fe1):
    zprint("downloading:%s"%(student_url))
    imgs=vi.flv2img_wget(student_url,1,0,100)
    face_num=0
    smile_num=0
    half_face_num=0
    c=0
    smile_score_l=[]
    top_l=[]
    left_l=[]
    size_l=[]
    smile_image=[]
    for img in imgs:
        score,rect,time_cost=fe1.face_emotion(img)
        if(len(score)==0):
            score.append(0)
        else:
            face_num+=1
        if(len(rect)==0):
            rect.append(fe1.rect_opencv2dlib([1,1,2,2]))
        sys.stdout.write("\r"+40*" ")
        sys.stdout.write("\r%5s/%5s,%5s,%15s"%(c,len(imgs),score,rect))
        sys.stdout.flush()
        sl=score
        dl=rect
        smile_score_l.append(sl[0])
        top_l.append(float(dl[0].top())/float(img.shape[0]))
        left_l.append(float(dl[0].left())/float(img.shape[1]))
        size_l.append(  float(float(dl[0].bottom())-float(dl[0].top()))/float(img.shape[0]))
        if(sl[0]>0.8):
            smile_image.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
            smile_num+=1
        c+=1
    info={"smile_image":smile_image,"face_num":face_num,"smile_num":smile_num,"half_face_num":half_face_num,"smile_score_l":smile_score_l,"top_l":top_l,"left_l":left_l,"size_l":size_l}
    return info 
def analysis_class(url,fe1,role="teacher"):
    #    {1:{"video":{"student_face_url":null,"teacher_face_url":null,"student_is_happy":null,"teacher_is_happy":null,"teacher_hand_gesture":null,"student_is_half_face":false,"teacher_is_half_face":false,"teacher_face_special":0.500000,"student_is_eye_closed":null,"teacher_is_eye_closed":null,"teacher_face_landmark":null,"student_face_landmark":null}}}
    info={}
    info[role]={} 
    try:
        if role=="teacher":
            info[role]=analysis_teacher(url,fe1)
        if role=="student":
            info[role]=analysis_student(url,fe1)
    except Exception as e:
        print("errro:%s"%e)
        info[role]['smile_image']=""

    info[role]['smile_image']=""
    zprint("%s"%info)
    
    return info
if __name__=="__main__":
    teacher_url="http://192.168.48.55/mp4/vipkid_jz30bdd2f5cbf849a39d2e07a4ebd95393_f_1530358219388_t_1530359737548.mp4"
    student_url="http://192.168.48.55/mp4/vipkid_jzbe5c90fd4a184fceab484531c77e9342_f_1530358219388_t_1530359737548.mp4"
    #analysis_class(teacher_url,student_url)
    analysis_class(teacher_url,fe0,"teacher")
    analysis_class(student_url,fe0,"student")



import cv2
from zprint import *
import numpy as np    
import math
import pdb
from distutils.sysconfig import get_python_lib
import os
import pandas as pd
import numpy as np
from sklearn.ensemble import RandomForestClassifier
from sklearn.model_selection import GridSearchCV
from sklearn import cross_validation, metrics
from sklearn.externals import joblib
import pdb

data_dir="/data1/mingmingzhao/data_sets/luminance"
sppath=get_python_lib()
mpath=os.path.join(sppath,"ai_tools/data/clf.pkl")
print("%s exits: %s"%(mpath,os.path.exists(mpath)))
clf=joblib.load(mpath)
def splitimage(image,n_row,n_col):
    w=image.shape[0]
    h=image.shape[1]
    ws=w/n_col
    hs=h/n_row
    splits=[]
    for i in range(0,w,ws):
        for j in range(0,h,hs):
            tmp=image[j:j+hs,i:i+ws]
            #print tmp.shape,i,j,ws,hs
            tmp1=tmp.reshape((ws*hs))
            splits.append(tmp1)
            
    return splits 
def weights_sum(vallist,weights):
    #weights=[0.1,0.1.0.1,0.1,0.2,0.1,0.1,0.1,0.1]
    c=[]
    i=0
    v=0.0
    ws=0.0
    for iv in vallist:
        
        c.append(iv*weights[i])
        #print c
        v+=c[-1]
        #ws+=weights[i]
        i+=1
    #v=v/ws
    return v 

def analysys_luminance(image_list):
    c=[]
    weights=[0.1,0.1,0.1,0.1,0.2,0.1,0.1,0.1,0.1]
    i=0
    mean_i=[]
    val_i=[]
    min_i=[]
    max_i=[]
    for image in image_list:
        image=image/255.0
        #print image.mean(),image.var(),min(image),max(image)
        mean_i.append(image.mean())
        val_i.append(image.var())
        min_i.append(min(image))
        max_i.append(max(image)) 
        i+=1
    
    #print mean_i 
    mean_lumi=weights_sum(mean_i,[0.1,0.1,0.1,0.1,0.2,0.1,0.1,0.1,0.1])
    hori_lumi=weights_sum(mean_i,[  1,  1,  1,  0,  0,  0, -1, -1, -1])
    vert_lumi=weights_sum(mean_i,[  1,  0, -1,  1,  0, -1,  1,  0, -1])
    slop_lumi=weights_sum(mean_i,[  0, -1, -1,  1,  0, -1,  1,  1,  0])
    tl_lumi  =weights_sum(mean_i,[  1,  0,  0,  0,  0,  0,  0,  0,  0])
    tr_lumi  =weights_sum(mean_i,[  0,  0,  0,  0,  0,  0,  1,  0,  0])
    lumi={}
    lumi['mean']=mean_lumi
    lumi['hori']=hori_lumi
    lumi['vert']=vert_lumi
    lumi['slop']=slop_lumi
    lumi['tl']=tl_lumi
    lumi['tr']=tr_lumi
    lumi['max']=max(mean_i)
    lumi['min']=min(mean_i)


    return lumi 
def get_Y(image):
    xyz=cv2.cvtColor(image,cv2.COLOR_BGR2XYZ)
    #cv2.cvtColor(image,xyz,cv2.COLOR_BGR2GRAY)
    channels=cv2.split(xyz)
    Yt=channels[1]
    return Yt
def get_sp(image):
    Yt=get_Y(image)
    Y=cv2.resize(Yt,(300,300),interpolation=cv2.INTER_CUBIC)
    sp=splitimage(Y,3,3)
    return sp
def luminance(image):
    sp=get_sp(image)
    zprint("lensp=%s"%(len(sp)))
    luminance=analysys_luminance(sp)
    #print luminance 
    return luminance
def nhist(image,bins_num=256,is_Y=0):
    if is_Y==0:
        y=get_Y(image)
    else:
        y=image
    hist=np.zeros((256))
    #pdb.set_trace()
    hist_n=np.zeros((bins_num+1))
    hist_x=np.zeros((bins_num+1))
    for i in range(0,bins_num+1):
        hist_x[i]=i
    #for yc in y.reshape((y.shape[0]*y.shape[1])):
    for yc in y:
        hist[yc]+=1
    #zprint(hist)
    for i in range(0,256):
        index=int(math.floor(float(i)/(256.0/float(bins_num))))
        #zprint("%s,%s"%(i,index))
        hist_n[index]+=hist[i]
    hist_n/=hist_n.sum()
    return hist_n,hist_x
def concat(a1,a2,direction=0):
    s1=a1.shape[0]
    s2=a2.shape[0]
    histo=np.zeros((s1+s2))
    histo[0:s1]=a1
    histo[s1:s1+s2]=a2
    return histo
    
def get_9hist(image):
    sp=get_sp(image)
    hist9=np.zeros((81))
    c=0
    for spc in sp:
        spc_hist,_=nhist(spc,9,1)
        hist9[c:c+9]=spc_hist[0:9]
        c+=9  
    #zprint(hist9)
    return hist9
def get_histfeature_from_one_img(img):
    histimg=np.zeros((1,117))
    hist36,_=nhist(img,36)
    hist81=get_9hist(img)
    #print(hist36.shape)
    #print(hist81.shape)

    hist117=concat(hist36,hist81)
    histimg[0,0:36]=hist36[0:36]*4
    histimg[0,36:36+81]=hist81[0:81]
    return histimg

def get_imglist_histfeature(imglist):
    if len(imglist)==0:
        return np.zeros((60,60))*-1
    histimg=np.zeros((len(imglist),117))
    for i in range(0,len(imglist)):
        zprint(i)
        img=imglist[i]
        hist36,_=nhist(img,36)
        hist81=get_9hist(img)
        print(hist36.shape)
        print(hist81.shape)

        hist117=concat(hist36,hist81)
        histimg[i,0:36]=hist36[0:36]*4
        histimg[i,36:36+81]=hist81[0:81]
    histimg=cv2.resize(histimg,(60,60),interpolation=cv2.INTER_CUBIC)
    return histimg
def lumi_classify_histimg(histimg):
    global clf 
    histimg*=255.0
    histimg.astype("uint8") 
    x=histimg.reshape((1,histimg.shape[0]*histimg.shape[1]))
    y_pred = clf.predict_proba(x)
    y_pred_sort_index=np.argsort(y_pred)
    y_pred_l=y_pred_sort_index[:,-1]
    ddict=["normal","darkest","darker","lighter","sun"]
    #ddict=["normal","darkest","darker","lighter","sun"]
    return ddict[y_pred_l[0]]
def lumi_classify(imglist):
    return lumi_classify_histimg(get_imglist_histfeature(imglist))
if __name__=="__main__":
    imgf="/root/jz9d701f00163d44ffa167d1e0455ea228_0_thumbnail.jpg"
    img=cv2.imread(imgf)
    #img=np.random.rand(60,60)
    hist_one= get_histfeature_from_one_img(img)
    pdb.set_trace()
    histimg=get_imglist_histfeature([img])
    print(lumi_classify_histimg(histimg))
    #image=cv2.imread("roc.jpg")
    image=cv2.imread(imgf)
    lumi=luminance(image)
    print(lumi)
    print(lumi['mean'])



import os
import shutil
    


def rmdirfile(dirname):
    files = os.listdir(dirname)
    for file in files:
        if os.path.getsize(file) < minSize * 1000:
            os.remove(file)    #删除文件
            print(file + " deleted")
def rmdir(dirname):
    if os.path.isdir(dirname):
        shutil.rmtree(dirname)




import numpy
import imageio
from ai_tools import video2img as vi
from vcvf_emotion import face_emotion as fe
import pdb
import os
import cv2
import sys           

fe0=fe.face_emotion()
def get_smile(images):
    images_smile=[]
    c=1
    for img in images:
        #rect=[96,96,185,186]
        #print(fe0.face_emotion_rect(img,rect))
        score,rect,time_cost=fe0.face_emotion(img)
	if(len(score)>0 and score[0]>0.8):
        	#images_smile.append(img)
        	images_smile.append(cv2.cvtColor(img,cv2.COLOR_BGR2RGB))
        	sys.stdout.write("\rlen(images),len(smile)=[%d,%d/%d],score=%s,%s"%(len(images),len(images_smile),c,score,score[0]>0.8))
        c=c+1
    return images_smile
def create_gif(gif_name,video_url):
    images=vi.flv2img(video_url,1,0,4000)
    image_smile=get_smile(images)

    dura=0.1
    #images=imageio.imiread("qq.gif")
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,53,12))]),duration=0.00001)
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,50,2))]),duration=0.1)
    imageio.mimsave(gif_name+"%s.gif"%(len(image_smile)*0.05),list(numpy.array(image_smile)[numpy.array(range(0,len(image_smile),2))]),duration=dura)
    print("gif duraton:%s s"%(len(image_smile)*0.1*0.5))
def create_gif_wget(gif_name,images):
    #images=vi.flv2img_wget(video_url,1,0,4000)
    #image_smile=get_smile(images)
    image_smile=images

    dura=0.1
    #images=imageio.imiread("qq.gif")
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,53,12))]),duration=0.00001)
    #imageio.mimsave("teacher.gif",list(numpy.array(images)[numpy.array(range(0,50,2))]),duration=0.1)
    imageio.mimsave(gif_name+"%s.gif"%(len(image_smile)*0.05),list(numpy.array(image_smile)[numpy.array(range(0,len(image_smile),2))]),duration=dura)
    print("gif duraton:%s s"%(len(image_smile)*0.1*0.5))
if __name__=="__main__":
    base_url="/data1/mingmingzhao/data_sets/mp4/"
    video_all="vipkid_jz3bc4e1e7458f49a381297ee384773637_f_1522312337659_t_1522313938697.mp4,vipkid_jz40c0afcf42a54577ae80a668a8593600_f_1532087814504_t_1532089561969.mp4,vipkid_jz932a9ba4f1fd4fd5809b333a366dd64a_f_1530336593475_t_1530338142709.mp4,vipkid_jzbfad3425917946f0abaafaea966117a9_f_1531744118258_t_1531745977835.mp4,vipkid_jzc0fc4672202b492594b3d094b010a6e1_f_1531826923257_t_1531828692939.mp4,vipkid_jzd28621035a7c4304805b38d397d148ae_f_1530872632184_t_1530874638548.mp4"
    video_list=video_all.split(',')
    for video in video_list:
        video_url=os.path.join(base_url,video)
        gif_name=video.split("_")[1]
        #pdb.set_trace()
        create_gif(gif_name,video_url)



# -*- coding: utf-8 -*-
import pylab as pl
from Analyze_txt import Analyze_txt
from roc_matrix import get_roc_matrix
import sys
from ai_tools import draw
from ai_tools import save2server
from zprint import *
import os
import pdb

def txt2xml(xmlfilename,txtfilename):
    with open(xmlfilename,'r') as fs:
            managerList=[]
            doc = xml.dom.minidom.Document()
            root = doc.createElement('Recognition')
            root.setAttribute('type', 'face')
            doc.appendChild(root)

            str=fs.read()
            line=str.split()
            print line
            for i in range(0,int(line[1])):
                managerList.append([{'xmin':line[2+i*4],'ymin':line[3+i*4],'xmax':line[4+i*4],'ymax':line[5+i*4]}])

            for i in managerList :
                for j in range(len(i)):
                    nodeManager = doc.createElement('bndbox')
                    nodeXmin = doc.createElement("xmin")
                    nodeXmin.appendChild(doc.createTextNode(i[j]['xmin']))
                    nodeYmin = doc.createElement("ymin")
                    nodeYmin.appendChild(doc.createTextNode(i[j]['ymin']))
                    nodeXmax = doc.createElement("xmax")
                    nodeXmax.appendChild(doc.createTextNode(i[j]['xmax']))
                    nodeYmax = doc.createElement("ymax")
                    nodeYmax.appendChild(doc.createTextNode(i[j]['ymax']))


                    nodeManager.appendChild(nodeXmin)
                    nodeManager.appendChild(nodeYmin)
                    nodeManager.appendChild(nodeXmax)
                    nodeManager.appendChild(nodeYmax)
                    root.appendChild(nodeManager)

            print line[0]
            #pathn=os.path.join(after_file,line[0])
            #pathn=os.path.join(pathn,".xml")
            #pathn+=".xml"
            #fp = open(pathn, 'w')
            fp = open(txtfilename, 'w')
            doc.writexml(fp, indent='\t', addindent='\t', newl='\n', encoding="utf-8")

def roc(standard_path="truth",test_path="test",result_roc='roc.txt',result_jpg='roc.jpg'):

    db=[]
    print "analyze_xml:"
    db,pos=Analyze_txt(standard_path,test_path)
    db = sorted(db, key=lambda x:x[2], reverse=True)#sorted() 
    
    print pos 
    xy_arr = []
    tp,fp = 0., 0.			
    for i in range(len(db)):
        #print db
        fp += db[i][1]#wrong
        tp += db[i][0]#creat
        xy_arr.append([fp,tp/pos,db[i][2]])
   

    auc = 0.			
    prev_x = 0
    for x,y,t in xy_arr:
	    if x != prev_x:
		    auc += (x - prev_x) * y
		    prev_x = x
            
    print xy_arr[-1]        
    x = [_a[0] for _a in xy_arr]
    y = [_a[1] for _a in xy_arr]
    y1 = [_a[2] for _a in xy_arr]
    #pl.title("ROC (AUC = %.4f)" % (auc/float(x[-1])))
    #pl.xlabel("False Count")
    #pl.ylabel("True Positive Rate")
    #pl.plot(x, y)
    #pl.show()
    xl=[x,x]
    yl=[y,y1]
    img=draw.draw_curve_new(xl,yl,width=512,height=512,title='ROC (AUC=%.4F)'%(auc/float(x[-1])),xlabel='FalseAlarm Count',ylabel='True Positive Rate') 
    save2server.save2server(result_jpg,img)
    with open(result_roc, 'w') as fp:
        for i in range(len(xy_arr)):
            fp.write("%f %f %f \n" % (xy_arr[i][0], xy_arr[i][1],xy_arr[i][2]))
def sort_matrix(db,pos,max_fa):
    db = sorted(db, key=lambda x:x[2], reverse=True)#sorted() 
    
    xy_arr = []
    tp,fp = 0., 0.			
    for i in range(len(db)):
        #print db
        
        fp += db[i][1]#wrong
        tp += db[i][0]#creat
        xy_arr.append([fp,tp/pos,db[i][2]])
   

    auc = 0.			
    prev_x = 0
    inds=0
    for x,y,t in xy_arr:
            inds+=1 if x<=max_fa else 0
	    if x != prev_x and x<=max_fa:
		    auc += (x - prev_x) * y
		    prev_x = x
            
    print xy_arr[-1]        
    x = [_a[0] for _a in xy_arr]
    y = [_a[1] for _a in xy_arr]
    y1 = [_a[2] for _a in xy_arr]
    func=lambda x: x[:inds]
    x=func(x)  
    y=func(y)  
    y1=func(y1)  
    #zprint(x)
    #pl.title("ROC (AUC = %.4f)" % (auc/float(x[-1])))
    #pl.xlabel("False Count")
    #pl.ylabel("True Positive Rate")
    #pl.plot(x, y)
    #pl.show()
    xl=[x,x]
    yl=[y,y1]
    #pdb.set_trace()
    return xl,yl,auc 
def roc_title(gt_dir,pre_dir,title_add='merge',save_path='./',max_fa=3500):
    roc_m,pos_number=get_roc_matrix(gt_dir,pre_dir)
    zprint("%r,ig%r"%(len(roc_m),pos_number)) 
    xl,yl,auc=sort_matrix(roc_m,pos_number,max_fa)
    #pdb.set_trace()
    result_txt=os.path.join(save_path,'%s_roc.txt'%(title_add))
    with open(result_txt, 'w') as fp:
        for i in range(len(xl[0])):
            fp.write("%f %f %f \n" % (xl[0][i],yl[0][i],yl[1][i]))
    
    xl0=xl
    yl0=yl
    #func=lambda x: x[:max_fa]
    #xl[0]=func(xl[0])  
    #xl[1]=func(xl[1])  
    #yl[0]=func(yl[0])  
    #yl[1]=func(yl[1])  
    zprint("%f,%f"%(auc,xl[0][-1]))
    img=draw.draw_curve_new(xl0,yl0,width=512,height=512,title='ROC (AUC=%.4F)%s'%(auc/float(xl[0][-1]),title_add),xlabel='FalseAlarm Count',ylabel='True Positive Rate') 
    result_jpg=os.path.join(save_path,'%s_roc.jpg'%(title_add))
    save2server.save2server(result_jpg,img)
    
    
if __name__ == '__main__':
    gt_dir=sys.argv[1]
    resultdir=sys.argv[2]
    print gt_dir
    print resultdir
    roc(gt_dir,resultdir,'result_roc.txt',"roc.jpg")



import cv2
import numpy as np
# zhaomingming
# 20180917
# the code for <<Single Image Haze Removal Using Dark Channel Prior>>


def get_Jc(img):
    print(img.shape)
    imgmin=img.min(2)
    Jc=imgmin.copy()
    print(imgmin.shape)
    #return img[:,:,0],img[:,:,1],img[:,:,2]
    return Jc 
def get_Jc_max(img):
    print(img.shape)
    imgmax=img.max(2)
    Jc=imgmax.copy()
    print(imgmax.shape)
    #return img[:,:,0],img[:,:,1],img[:,:,2]
    return Jc 
def get_Jdark_from_Jc(Jc,omiga_ridas=7):
    cols=Jc.shape[1]
    rows=Jc.shape[0]
    image=Jc 
    image_49channel=np.zeros((rows,cols,49))
    for i in range(0,7):
        for j in range(0,7):
            #affineShrinkTranslation = np.array([[0.5, 0, cols/4], [0, 0.5, rows/4]], np.float32)
            affineShrinkTranslation = np.array([[1, 0, i], [0, 1, j]], np.float32)
            shrinkTwoTimesTranslation = cv2.warpAffine(image, affineShrinkTranslation, (cols, rows), borderValue=255)
            image_49channel[:,:,i*7+j]=shrinkTwoTimesTranslation
    print(image_49channel.shape)
    Jdark=image_49channel.min(2)
    print(Jdark.shape) 
    return Jdark
def get_Jdark(img):
    Jc=get_Jc(img)
    return get_Jdark_from_Jc(Jc)
def get_Jdark_from_file(imgf):
    #img=cv2.imread("ai_tools/temp.jpg")
    img=cv2.imread(imgf)
    return get_Jdark(img)
def get_A_1(img,Jdark):
    # get the top 1% pix's position
    Jdarklist=np.zeros((3,Jdark.shape[0]*Jdark.shape[1]),dtype="int64")
    for i in range(0,Jdark.shape[0]):
        print(i,i*Jdark.shape[1])
        for j in range(0,Jdark.shape[1]):
            #Jdarklist[:,i*Jdark.shape[0]+j]=np.array((i,j,Jdark[i,j]))
            Jdarklist[0,i*Jdark.shape[1]+j]=i
            Jdarklist[1,i*Jdark.shape[1]+j]=j
            #Jdarklist[2,i*Jdark.shape[1]+j]=i*Jdark.shape[1]+j
            Jdarklist[2,i*Jdark.shape[1]+j]=Jdark[i,j]
            #print(np.array((i,j,i*Jdark.shape[0]+j),dtype="int64"))
    top_percent_one=int(round(Jdarklist[2,:].shape[0]*0.01))
    
    print(top_percent_one)
    sort_index=np.argsort(Jdarklist[2,:])
    print(sort_index)
    print(sort_index.shape)
    #print(Jdarklist[2,Jdark.shape[0]*Jdark.shape[1]-1-np.argsort(Jdarklist[2,:])])
    print(Jdarklist[2,np.argsort(Jdarklist[2,:])])
    top_x=Jdarklist[1,sort_index[-top_percent_one:-1]]
    top_y=(Jdarklist[0,sort_index[-top_percent_one:-1]])
    #print(Jdarklist[1,sort_index[-top_percent_one:-1]])
    #print(Jdarklist[0,sort_index[-top_percent_one:-1]])
     
    #print(Jdarklist[2,-10:-1])
    #print(Jdarklist[0,1:10])
def get_A(img,Jdark):
    # get the top 1% pix's position
    Jc_light=get_Jc_max(img)
    Jc_light_1=Jc_light.reshape((Jc_light.shape[0]*Jc_light.shape[1]))
    print(Jc_light_1)
    Jdark_1=Jdark.copy()
    Jdark_1=Jdark_1.reshape((Jdark_1.shape[0]*Jdark_1.shape[1]))
    top_num=int(round(Jdark_1.shape[0]*0.01))
    print(Jc_light_1[np.argsort(Jdark_1)])
    Jc_light_2=Jc_light_1[np.argsort(Jdark_1)]
    print("A=%s"%(Jc_light_2[-top_num:-1].max())) 
    A=Jc_light_2[-top_num:-1].max()
    A=float(A)
    print(type(A))
    A = 0.0001 if A == 0 else A
    print("A=%s"%(Jc_light_2[-top_num:-1].max())) 
    #return Jc_light_2[-top_num:-1].max()
    return A
def get_T(img,A):
    img1=img.astype(np.float64)
    
    A1=A
    #A1=A.astype(np.float64)
    print("A=%s,A1=%s"%(A,A1))
    T=1-0.5*get_Jdark(img1/A1)
    T[T<0.1]=0.1
    print("img1:")
    print(img1.shape)
    print(img1/A1)
    print(T.shape)
    return T
def c123(M):
    return np.stack([M,M,M],2)
def get_J_from_T(img,A,T):
    img1=img.astype(np.float64)
    #A1=A.astype(np.float64)
    A1=float(A)
    T1=T.astype(np.float64)
    J=(img1-A1)/T1+A1 
    return J

def get_J(img):
    Jdark = get_Jdark(img)
    cv2.imwrite("Jdark.png",Jdark)
    A = get_A(img,Jdark)
    T = get_T(img,A)
    J = get_J_from_T(img,A,c123(T))
    return J
def test():
    img=cv2.imread("ai_tools/temp.jpg")
    Jc=get_Jc(img)
    get_Jdark(Jc)
if __name__=="__main__":
    img=cv2.imread("ai_tools/temp.jpg")
    img=cv2.imread("haze_img1.png")
    get_Jdark(img)
    Jdark=get_Jdark_from_file("ai_tools/temp.jpg")
    cv2.imwrite("Jdark.jpg",Jdark)
    #get_A_1(img,Jdark)
    J=get_J(img)
    print(J)
    
    cv2.imwrite("haze_out.jpg",J)
